@@ -216,9 +216,12 @@ sub refresh_access_token {
             if (not (ref($tokens))) {
                 # Did I get JSON?
                 my $data = eval {decode_json($tokens)};
+
                 if ($data and not $@) {
-                    # Assume I got it.
-                    $tokens = $data;
+                    my $class = $data->{_class} or croak("No _class in token_string '$tokens'");
+                    eval {load($class)};
+                    if ($@) { croak("Can't load access token class '$class': $@"); }
+                    $tokens = $class->from_ref($data);
                 }
             }
             return $self->_set_tokens(tokens => $tokens, skip_save => 1);
@@ -335,7 +338,7 @@ Version 0.15
 
 =cut
 
-our $VERSION = '0.15';
+our $VERSION = '0.17';
 
 =head1 SYNOPSIS
 
@@ -384,6 +387,12 @@ L<LWP::Authen::OAuth2::ServiceProvider::Strava>
 
 implemented by L<Leon Wright|https://github.com/techman83>
 
+=item * Yahoo
+
+L<LWP::Authen::OAuth2::ServiceProvider::Yahoo>
+
+implemented by L<Michael Stevens|https://github.com/michael-stevens>
+
 =back
 
 You can also access any other OAuth2 service by setting up a plain C<LWP::Authen::OAuth2> object. If you do, and the service provider might be of interest to other people, please submit a patch so we can include it in this distribution, or release it as a standalone package.
@@ -642,7 +651,7 @@ tokens too quickly, so this can be important.
 =item C<user_agent =E<gt> $ua,>
 
 What user agent gets used under the hood?  Defaults to a new
-L<lWP::UserAgent> created on the fly.
+L<LWP::UserAgent> created on the fly.
 
 =back
 
@@ -831,7 +840,7 @@ You can also look for information at:
 
 =item Github (submit patches here)
 
-L<https://github.com/btilly/perl-oauth2>
+L<https://github.com/domm/perl-oauth2>
 
 =item RT: CPAN's request tracker (report bugs here)
 
@@ -845,9 +854,9 @@ L<http://annocpan.org/dist/LWP-Authen-OAuth2>
 
 L<http://cpanratings.perl.org/d/LWP-Authen-OAuth2>
 
-=item Search CPAN
+=item MetaCPAN
 
-L<http://search.cpan.org/dist/LWP-Authen-OAuth2/>
+L<https://metacpan.org/release/LWP-Authen-OAuth2>
 
 =back
 
@@ -878,6 +887,8 @@ C<ServiceProvider> work without requiring subclassing.
 
 =item * L<Adam Millerchip|https://github.com/amillerchip> for adding a L<Line | https://line.me> Service Provider and some refactoring
 
+=item * L<Michael Stevens|https://github.com/mstevens> for adding a C<Yahoo | https://developer.yahoo.com> Service Provider and some dist cleanup
+
 =item * Nick Morrott for fixing some documentation typos
 
 =back
