@@ -386,7 +386,7 @@ sub request_required_params {
 }
 
 sub request_optional_params {
-    return qw(state);
+    return qw(state redirect_uri);
 }
 
 sub request_default_params {
@@ -464,8 +464,16 @@ hopefully useful configuration and documentation:
 
 =over 4
 
+=item L<LWP::Authen::OAuth2::ServiceProvider::Dwolla|Dwolla>
+
 =item L<LWP::Authen::OAuth2::ServiceProvider::Google|Google>
 
+=item L<LWP::Authen::OAuth2::ServiceProvider::Line|Line>
+
+=item L<LWP::Authen::OAuth2::ServiceProvider::Strava|Strava>
+
+=item L<LWP::Authen::OAuth2::ServiceProvider::Yahoo|Yahoo>
+
 =back
 
 =head1 SUBCLASSING
@@ -509,7 +517,7 @@ provider.  Your subclass cannot function without this.
 
 This method receives your class name and the passed in C<client_type>.
 It is supposed to make sure that the class that handles that
-C<client_type> is loaded, and then return it.  This let's you handle service
+C<client_type> is loaded, and then return it.  This lets you handle service
 providers with different behavior for different types of clients.
 
 The base implementation just returns your class name.
